#  Copyright (c) 2006 Six Feet Up, Inc.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
Base ad to create Ad types with
"""
from Globals import InitializeClass

from Products.CMFCore import CMFCorePermissions
from Products.CMFCore.utils import getToolByName
from Products.Archetypes import atapi
from Products.ATReferenceBrowserWidget.ATReferenceBrowserWidget \
    import ReferenceBrowserWidget
from Products.PromoEngine.config import PROJECTNAME

BaseAdSchema = atapi.BaseSchema.copy() + atapi.Schema((
    atapi.ReferenceField(
        'adLocation',
        multiValued = True,
        relationship = 'AdLocation',
        widget = ReferenceBrowserWidget(
            label = 'Ad Location Step 1',
            description = """Select where the ad should show up""",
            startup_directory = '/',
        ),
    ),
    atapi.StringField(
        'adSlot',
        vocabulary = 'getSlotVocab',
        index = 'ad_catalog/FieldIndex',
        widget = atapi.SelectionWidget(
            label = 'Ad Location Step 2',
            description = """Select an optional slot to use""",
            ),
    ),
))

class BaseAd(atapi.BaseContent):
    """Base ad class to create different types of ads
    """
    schema = BaseAdSchema
    global_allow = 0
    content_icon = 'ad_icon.gif'

    def getSlotVocab(self):
        ad_tool = getToolByName(self, 'ad_manager')
        raw_ad_slots = ad_tool.getSlots()
        ad_slots = [(slot, slot) for slot in raw_ad_slots]
        return atapi.DisplayList(ad_slots)
    
    # XXX VariableSchemaSupport is not working with this subclassing
    #def getSchema(self):
    #    ad_tool = getToolByName(self, 'portal_ad_manager')
    #    newschema = self.schema
    #    #get the allowed types
    #    ad_locations = ad_tool.getAdLocations()
    #    ad_links = ad_tool.getAdLinks()
    #    # set the allowed types for links and location
    #    newschema['adLocation'].allowed_types = ad_locations
    #    newschema['adLinkInternal'].allowed_types = ad_links
    #    return self.schema + newschema
           
InitializeClass(BaseAd)
