# imports for the dependencies
from ZODB.POSException import ConflictError
from os.path import join, abspath, dirname
import ZConfig

from Products.CMFCore.utils import getToolByName

## Configuration utilities
DIR_PATH = abspath(dirname(__file__))

def conf_file(file):
    return join(DIR_PATH, 'conf', file)

def doc_file(file):
    return join(DIR_PATH, 'docs', file)

def register(portal, pkg):
    qi = getToolByName(portal, 'portal_quickinstaller')
    if qi.isProductInstalled(pkg):
        qi.reinstallProducts((pkg,))
    else:
        qi.installProduct(pkg)

def requires(portal, pkg):
    """Make sure that we can load and install the package into the site"""
    register(portal, pkg)

def optional(portal, pkg):
    try:
        register(portal, pkg)
        return True
    except ConflictError:
        raise
    except:
        return False

def parseDependencies():
    schema = ZConfig.loadSchema(conf_file('depends.xml'))
    config, handler = ZConfig.loadConfig(schema,
                                         conf_file('depends.conf'))
    return config, handler

def installDependencies(portal):
    config, handler = parseDependencies()
    # Curry up some handlers
    def required_handler(values, portal=portal):
        for pkg in values:
            requires(portal, pkg)

    def optional_handler(values, portal=portal):
        for pkg in values:
            optional(portal, pkg)

    handler({'required' : required_handler,
             'optional' : optional_handler,
             })

def addSchemataOrdered(*schemata):
    """Add all fields from the given schemata into one schema
    preserving order and field overrides."""
    result = schemata[0].copy()
    for schema in schemata[1:]:
        result = result + schema.copy()
    reversed = list(schemata[:-1])
    reversed.reverse()
    for schema in reversed:
        result = result + schema.copy()
    return result
